/**
 *@function
 * @name:Deep copy
 * @param {Object} obj Objects to copy
 * @returns {Object} Deep copy of the object
 */
export declare function deepClone(values: any): any;
/**
* @name: Shallow copy
* @param {Object} obj Objects to copy
* @returns {Object} Shallow copy of the object
*/
export declare function shallowClone<T>(obj: T): T;
/**
* @name:Get the number of object attributes
* @param {Object} obj To get an object of the number of properties
*/
export declare function getObjectLength(obj: object): number;
/**
* @name: Time format X days ago
* @param {*} time Timestamp
* @return {*} Time format X days ago
* @example
* console.log(timeFormat(1588888888)); // 2 days ago
*/
export declare function timeFormat(time: any): any;
/**
* @name: Package Ajax Promise
* @param {String} url Request address
* @param {Object} data Request parameters
* @param {String} method Request way get/post
* @returns {Promise}
*/
export declare function ajax({ url, data, method }: {
    url: string;
    data: any;
    method: string;
}): Promise<any>;
/**
* @name: Judging whether the array contains a value
* @param {Array} arr Array to be judged
* @param {any} value To determine the value
*/
export declare function isContain(arr: any[], value: any): boolean;
/**
* @name: Array to heavy
* @param {Array} arr Array to be heavy
* @returns {Array}
* @example
* console.log(unique([1,2,3,4,5,6,7,8,9,10,1,2,3,4,5,6,7,8,9,10])) // [1,2,3,4,5,6,7,8,9,10]
*/
export declare function unique(arr: any[]): any[];
/**
* @name: Generate random colors
* @return {String} Random color
* @example
* console.log(randomColor()) // #e6e6e6
*/
export declare function randomColor(): string;
/**
* @name: Array sort
* @param {Array} arr Array to be sorted
* @param {String} key Sort KEY
* @param {String} order Sort mode, ASC ascending, DESC descending
* @example
* sortBy([{name: 'a'}, {name: 'b'}], 'name', 'asc')
* // => [{name: 'a'}, {name: 'b'}]
* sortBy([{name: 'a'}, {name: 'b'}], 'name', 'desc')
* // => [{name: 'b'}, {name: 'a'}]
* sortBy([{name: 'a'}, {name: 'b'}], 'name')
* // => [{name: 'a'}, {name: 'b'}]
*/
export declare function sortBy(arr: any[], key: string, order?: string): any[];
/**
* @name: Random verification code
* @param {Number} len Verification code length
*/
export declare function randomCode(len: number): string;
/**
* @name: Password verification regular
* @param {String} password password
* @returns {Boolean}
*/
export declare function checkPassword(password: string): boolean;
/**
* @name: Regular verification mailbox
* @param {String} email Mail
* @returns {Boolean}
*/
export declare function checkEmail(email: string): boolean;
/**
* @name: Regular verification mobile phone number
* @param {String} phone phone number
* @param {Boolean} isChina Is it a Chinese mobile phone number?
* @returns {Boolean}
*/
export declare function checkPhone(phone: string, isChina?: boolean): boolean;
/**
* @name: Regular verification ID card number
* @param {String} idCard ID number
* @returns {Boolean}
*/
export declare function checkIdCard(idCard: string): boolean;
/**
* @name: Regular verification bank card number
* @param {String} bankCard Bank card number
* @returns {Boolean}
*/
export declare function checkBankCard(bankCard: string): boolean;
/**
* @name:Judging the mobile phone system
*/
export declare function checkPhoneSystem(): {
    isAndroid: boolean;
    isiOS: boolean;
};
/**
* @name: Judging the mobile phone number home
* @param {String} phone phone number
*/
export declare function getPhoneAttribution(phone: string): Promise<unknown>;
interface setting {
    method?: string;
    body?: any;
    headers?: any;
    mode?: string;
    credentials?: any;
    cache?: string;
    redirect?: string;
    dataType?: string;
    data?: any;
}
/**
* @name: Package FETCH request
* @param {string} url Request address
* @param {string} setting Request configuration
* @return {Promise} Request promise
*/
export declare function fetch(url: string, setting: setting): Promise<unknown>;
/**
 * @name: Determine if it is a PC
 * @return {Boolean} true or false
 */
export declare function isPC(): boolean;
/**
* @name: Remove string spaces
* @param {string} str String
* @param {string} type Type 1: All space type 2: front and rear space type 3: Front space type 4: rear
* @returns {string} String
*/
export declare function trim(str: string, type: number): string;
/**
* @name: Filter HTML code
* @param {string} str String
* @return {string} String
*/
export declare function filterHTML(str: string): string;
/**
* @name: Judging whether it is a floating point number
* @param {any} val
* @return {boolean}
*/
export declare function isFloat(val: any): boolean;
/**
 * @name: Judgment is an integer
 * @param {any} val
 * @return {boolean}
 */
export declare function isInteger(val: any): boolean;
/**
* @name: Object serialization
* @param  {Object} obj
* @return {String}
*/
export declare function stringifyQueryString(obj: any): string;
/**
 * @desc Get the distance from the top of the scroll bar
 * @return {Number} The distance from the top of the scroll bar
 */
export declare function getScrollTop(): number;
/**
 *
 * @desc H5 soft keyboard is retracted, bounce back
 * When the software keyboard pops up will change the current Window.innerHeight, monitor this value change
 * @param {Function} downCb When the soft keyboard bounces, the retracted callback
 * @param {Function} upCb When the soft keyboard bounces
 * @return {Function}
 */
export declare function windowResize(downCb: Function, upCb: Function): void;
export {};
